@@ -23,8 +23,8 @@
 
    Fotoxx window and menu build functions
 
-   build_widgets           build widgets and menus for F/G/W view modes
-   m_viewmode              set current F/G/W view mode
+   build_widgets           build widgets and menus for F/G/W/M view modes
+   m_viewmode              set current F/G/W/M view mode
    popup_menufunc          image/thumb right-click menu func
    image_Rclick_popup      popup menu for image right-click
    gallery_Lclick_func     thumbnail left-click function
@@ -43,18 +43,18 @@ GtkWidget   *mFile, *mTools, *mBatch, *mAlbums, *mMeta, *mArea;
 GtkWidget   *mEdit, *mRep, *mBend, *mEff, *mComb, *mHelp;
 
 GtkWidget   *popmenu_main, *popmenu_thumb, *popmenu_album, *popmenu_raw;
-int         NFmenu, NGmenu, NWmenu;
+int         NFmenu, NGmenu, NWmenu, NMmenu;
 
 
-//  initialize widgets and menus for F/G/W view modes
+//  initialize widgets and menus for F/G/W/M view modes
 //  called from main() before gtk_main() loop is entered
 
 void build_widgets()
 {
    Mwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);                                   //  create main window
    gtk_window_set_title(MWIN,Frelease);
-   Mvbox = gtk_box_new(VERTICAL,0);                                              //  top container
-   gtk_container_add(GTK_CONTAINER(Mwin),Mvbox);
+   MWvbox = gtk_box_new(VERTICAL,0);                                             //  top container
+   gtk_container_add(GTK_CONTAINER(Mwin),MWvbox);
    gtk_widget_show_all(Mwin);
 
    G_SIGNAL(Mwin,"delete_event",delete_event,0);                                 //  connect signals to main window
@@ -67,13 +67,13 @@ void build_widgets()
    
    //  get hardware and set default font for screen widgets
    
-   get_hardware_info(Mwin);                                                      //  GTK API broken again               15.09
-   g_object_set(zfuncs::settings,"gtk-font-name",dialog_font,null);              //  set font for screen                15.09
+   get_hardware_info(Mwin);
+   zsetfont(dialog_font);
 
    //  F view widgets - image file
 
    Fhbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
-   gtk_box_pack_start(GTK_BOX(Mvbox),Fhbox,1,1,0);
+   gtk_box_pack_start(GTK_BOX(MWvbox),Fhbox,1,1,0);
    Fmenu = gtk_box_new(VERTICAL,0);                                              //  left vbox for vert. menu
    gtk_box_pack_start(GTK_BOX(Fhbox),Fmenu,0,0,0);
    Fvbox = gtk_box_new(VERTICAL,0);                                              //  right vbox for image
@@ -102,7 +102,7 @@ void build_widgets()
    //  G view widgets - thumbnail gallery
 
    Ghbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
-   gtk_box_pack_start(GTK_BOX(Mvbox),Ghbox,1,1,0);
+   gtk_box_pack_start(GTK_BOX(MWvbox),Ghbox,1,1,0);
    Gmenu = gtk_box_new(VERTICAL,0);                                              //  left vbox for vert. menu
    gtk_box_pack_start(GTK_BOX(Ghbox),Gmenu,0,0,0);
    Gvbox = gtk_box_new(VERTICAL,0);                                              //  right vbox for gallery
@@ -113,8 +113,9 @@ void build_widgets()
    gtk_box_pack_start(GTK_BOX(Gpanel),Galbum,0,0,3);
    Gtop = gtk_button_new_with_label(ZTX("TOP"));                                 //  [TOP] button in panel
    gtk_box_pack_start(GTK_BOX(Gpanel),Gtop,0,0,3);
-   Gsep = gtk_separator_new(VERTICAL);                                           //  separator line
-   gtk_box_pack_start(GTK_BOX(Gpanel),Gsep,0,0,3);
+   Gsep = gtk_label_new(0);
+   gtk_label_set_markup(GTK_LABEL(Gsep),"<span font=\"sans bold 12\" >@</span>");
+   gtk_box_pack_start(GTK_BOX(Gpanel),Gsep,0,0,10);
 
    Gsep = gtk_separator_new(HORIZONTAL);                                         //  separator line
    gtk_box_pack_start(GTK_BOX(Gvbox),Gsep,0,0,3);
@@ -139,7 +140,7 @@ void build_widgets()
    //  W view widgets - geomaps
 
    Whbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
-   gtk_box_pack_start(GTK_BOX(Mvbox),Whbox,1,1,0);
+   gtk_box_pack_start(GTK_BOX(MWvbox),Whbox,1,1,0);
    Wmenu = gtk_box_new(VERTICAL,0);                                              //  left vbox for vert. menu
    gtk_box_pack_start(GTK_BOX(Whbox),Wmenu,0,0,0);
    Wvbox = gtk_box_new(VERTICAL,0);                                              //  right vbox for geomap
@@ -159,13 +160,25 @@ void build_widgets()
    G_SIGNAL(Wdrawin,"scroll-event",mouse_event,0);
    G_SIGNAL(Wdrawin,"draw",Fpaint,0);
 
+   //  M view widgets - OSM maps                                                 //  OSM                                16.05
+
+   Mhbox = gtk_box_new(HORIZONTAL,0);                                            //  top container
+   gtk_box_pack_start(GTK_BOX(MWvbox),Mhbox,1,1,0);
+   Mmenu = gtk_box_new(VERTICAL,0);                                              //  left vbox for vert. menu
+   gtk_box_pack_start(GTK_BOX(Mhbox),Mmenu,0,0,0);
+   Mvbox = gtk_box_new(VERTICAL,0);                                              //  right vbox for OSM map
+   gtk_box_pack_start(GTK_BOX(Mhbox),Mvbox,1,1,0);
+   gtk_widget_hide(Mhbox);
+
+
    //  menu popup text (tool tips) ----------------------------------------
    
-   //  F/G/W view menu buttons
+   //  F/G/W/M view menu buttons
 
    cchar * imagefile_tip = ZTX("Current Image File (key F)");
    cchar * gallery_tip = ZTX("Thumbnail Gallery (key G)");
    cchar * worldmaps_tip = ZTX("World Maps (key W)");
+   cchar * OSMmaps_tip = ZTX("OSM Maps (key M)");                                //  OSM                                16.05
 
    //  F view menu buttons
    cchar * favorites_tip = ZTX("Favorite Functions");
@@ -202,6 +215,12 @@ void build_widgets()
    //  W view menu buttons
    cchar * load_geomap_tip = ZTX("Choose a map for image locations");
    cchar * mapsearch_tip = ZTX("Set image search radius for map click");
+   cchar * geotag_groups_tip = ZTX("Find all images for a location [date]");
+   cchar * search_images_tip = ZTX("Find images meeting select criteria");
+
+   //  M view menu buttons                                                       //  OSM                                16.05
+   //  geotag_groups_tip (duplicate of W view)
+   //  search_images_tip (duplicate of W view)
 
    //  file popup menu
    cchar * clone_tip = ZTX("Open another window");
@@ -232,8 +251,8 @@ void build_widgets()
    cchar * batch_report_metadata_tip = ZTX("Report metadata for multiple images");
    cchar * edit_geotags_tip = ZTX("Edit image location and geotags");
    cchar * batch_geotags_tip = ZTX("Add/revise geotags for multiple images");
-   cchar * geotag_groups_tip = ZTX("Find all images for a location [date]");
-   cchar * search_images_tip = ZTX("Find images meeting select criteria");
+   //  geotag_groups_tip
+   //  search_images_tip
 
    //  select area popup menu
    cchar * select_tip = ZTX("Select object or area for editing");
@@ -274,6 +293,7 @@ void build_widgets()
    cchar * redeye_tip = ZTX("Fix red-eyes from electronic flash");
    cchar * paint_clone_tip = ZTX("Paint image pixels using the mouse");
    cchar * paint_transp_tip = ZTX("Paint image transparency using the mouse");
+   cchar * add_transp_tip = ZTX("Add image transparency based on image attributes");
    cchar * color_mode_tip = ZTX("Make BW/color, negative/positive, sepia");
    cchar * shift_colors_tip = ZTX("Shift/convert colors into other colors");
    cchar * color_sat_tip = ZTX("Adjust color intensity (saturation)");
@@ -296,6 +316,7 @@ void build_widgets()
    cchar * warp_affine_tip = ZTX("Distort the whole image using the mouse");
    cchar * flatbook_tip = ZTX("Flatten a photographed book page");
    cchar * sphere_tip = ZTX("Make a spherical projection of an image");
+   cchar * selective_rescale_tip = ZTX("Rescale image outside selected areas");
 
    //  effects popup menu
    cchar * colordep_tip = ZTX("Reduce color depth (posterize)");
@@ -315,6 +336,7 @@ void build_widgets()
    cchar * anykernel_tip = ZTX("Process an image using a custom kernel");
    cchar * waves_tip = ZTX("Warp an image with a wave pattern");
    cchar * dirblur_tip = ZTX("Blur an image in the direction of mouse drags");
+   cchar * blur_BG_tip = ZTX("Increasing blur with distance from selected areas");
 
    //  combine popup menu
    cchar * HDR_tip = ZTX("Combine bright/dark images for better detail");
@@ -354,7 +376,7 @@ void build_widgets()
    cchar * burn_tip = ZTX("Burn selected image files to DVD/BlueRay disc");
    cchar * duplicates_tip = ZTX("Search all image files and report duplicates");
    cchar * imagelist_tip = ZTX("Create a file of selected image files");
-   //  metadata batch functions included here
+   //  metadata batch functions are duplicated here
 
    //  help popup menu
    cchar * quick_start_tip = ZTX("Quick Start mini-guide");
@@ -466,6 +488,7 @@ void build_widgets()
    MENUENT(mRep,     ZTX("Red Eyes"), 0,              redeye_tip,             m_redeye, 0 );
    MENUENT(mRep,     ZTX("Paint/Clone"), 0,           paint_clone_tip,        m_paint_clone, 0 );
    MENUENT(mRep,     ZTX("Paint Transparency"), 0,    paint_transp_tip,       m_paint_transp, 0 );
+   MENUENT(mRep,     ZTX("Add Transparency"), 0,      add_transp_tip,         m_add_transp, 0 );
    MENUENT(mRep,     ZTX("Color Mode"), 0,            color_mode_tip,         m_color_mode, 0 );
    MENUENT(mRep,     ZTX("Shift Colors"), 0,          shift_colors_tip,       m_shift_colors, 0 );
    MENUENT(mRep,     ZTX("Color Saturation"), 0,      color_sat_tip,          m_colorsat, 0 );
@@ -488,7 +511,8 @@ void build_widgets()
    MENUENT(mBend,    ZTX("Warp linear"), 0,           warp_linear_tip,        m_warp_linear, 0 );
    MENUENT(mBend,    ZTX("Warp affine"), 0,           warp_affine_tip,        m_warp_affine, 0 );
    MENUENT(mBend,    ZTX("Flatten Book Page"), 0,     flatbook_tip,           m_flatbook, 0 );
-   MENUENT(mBend,    ZTX("Spherical Projection"), 0,  sphere_tip,          m_sphere, 0);
+   MENUENT(mBend,    ZTX("Spherical Projection"), 0,  sphere_tip,             m_sphere, 0);
+   MENUENT(mBend,    ZTX("Selective Rescale"), 0,     selective_rescale_tip,  m_selective_rescale, 0);
 
    mEff = create_popmenu();
    MENUENT(mEff,     ZTX("Color Depth"), 0,           colordep_tip,        m_colordep, 0 );
@@ -508,6 +532,7 @@ void build_widgets()
    MENUENT(mEff,     ZTX("Custom Kernel"), 0,         anykernel_tip,       m_anykernel, 0);
    MENUENT(mEff,     ZTX("Make Waves"), 0,            waves_tip,           m_waves, 0);
    MENUENT(mEff,     ZTX("Directed Blur"), 0,         dirblur_tip,         m_dirblur, 0);
+   MENUENT(mEff,     ZTX("Blur Background"), 0,       blur_BG_tip,         m_blur_BG, 0);
 
    mComb = create_popmenu();
    MENUENT(mComb,    ZTX("High Dynamic Range"), 0,       HDR_tip,             m_HDR, 0 );
@@ -579,6 +604,7 @@ void build_widgets()
    MENUENT(0,  ZTX("Image"),        "viewF-check.png",   imagefile_tip,       m_viewmode, "F" );
    MENUENT(0,  ZTX("Gallery"),      "viewG.png",         gallery_tip,         m_viewmode, "G" );
    MENUENT(0,  ZTX("World Maps"),   "viewW.png",         worldmaps_tip,       m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),     "viewM.png",         OSMmaps_tip,         m_viewmode, "M" );               //  OSM  16.05
    MENUENT(0,  0,                   "separator.png",     0,                   0,           0  );
    MENUENT(0,  ZTX("Favorites"),    "favorites.png",     favorites_tip,       m_favorites, 0 );
    MENUENT(0,  ZTX("File"),         "file.png",          file_tip,            (cbFunc *) popup_menu, (cchar *) mFile);
@@ -602,6 +628,7 @@ void build_widgets()
    MENUENT(0,  ZTX("Image"),        "viewF.png",         imagefile_tip,          m_viewmode, "F" );
    MENUENT(0,  ZTX("Gallery"),      "viewG-check.png",   gallery_tip,            m_viewmode, "G" );
    MENUENT(0,  ZTX("World Maps"),   "viewW.png",         worldmaps_tip,          m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),     "viewM.png",         OSMmaps_tip,            m_viewmode, "M" );            //  OSM  16.05
    MENUENT(0,  0,                   "separator.png",     0,                      0,           0  );
    MENUENT(0,  ZTX("Favorites"),    "favorites.png",     favorites_tip,          m_favorites, 0 );
    MENUENT(0,  ZTX("Sync Gallery"), "sync.png",          sync_tip,               navi::menufuncx, 0 );
@@ -625,6 +652,7 @@ void build_widgets()
    MENUENT(0,  ZTX("Image"),              "viewF.png",            imagefile_tip,       m_viewmode, "F" );
    MENUENT(0,  ZTX("Gallery"),            "viewG.png",            gallery_tip,         m_viewmode, "G" );
    MENUENT(0,  ZTX("World Maps"),         "viewW-check.png",      worldmaps_tip,       m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),           "viewM.png",            OSMmaps_tip,         m_viewmode, "M" );      //  OSM  16.05
    MENUENT(0,  0,                         "separator.png",        0,                   0,           0  );
    MENUENT(0,  ZTX("Choose Map"),         "choosemap.png",        load_geomap_tip,     m_load_geomap, 0 );
    MENUENT(0,  ZTX("Search Range"),       "setmaprange.png",      mapsearch_tip,       m_mapsearch_range, 0 );
@@ -633,18 +661,32 @@ void build_widgets()
 
    NWmenu = Nmenus;
 
+   //  M view menu (buttons)                                                     //  OSM                                16.05
+
+   MENUENT(0,  ZTX("Image"),              "viewF.png",            imagefile_tip,       m_viewmode, "F" );
+   MENUENT(0,  ZTX("Gallery"),            "viewG.png",            gallery_tip,         m_viewmode, "G" );
+   MENUENT(0,  ZTX("World Maps"),         "viewW.png",            worldmaps_tip,       m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),           "viewM-check.png",      OSMmaps_tip,         m_viewmode, "M" );
+   MENUENT(0,  0,                         "separator.png",        0,                   0,           0  );
+   MENUENT(0,  ZTX("Images by Geotag"),   "search.png",           geotag_groups_tip,   m_geotag_groups, 0 );
+   MENUENT(0,  ZTX("Search Images"),      "search.png",           search_images_tip,   m_search_images, 0 );
+
+   NMmenu = Nmenus;
+
    //  dummy menus only for KB shortcuts
 
    MENUENT(0,  ZTX("Undo"),               "KB shortcut",    0,    m_undo, 0 );
    MENUENT(0,  ZTX("Redo"),               "KB shortcut",    0,    m_redo, 0 );
-   MENUENT(0,  ZTX("Save File Version"),  "KB shortcut",    0,    m_file_save_version, 0);                    //  15.12
+   MENUENT(0,  ZTX("Save File Version"),  "KB shortcut",    0,    m_file_save_version, 0);                          //  15.12
 
-   //  build the vertical menus for the F/G/W windows
+   //  build the vertical menus for the F/G/W/M windows
 
    Vmenu *Fvm = Vmenu_new(Fmenu);
    Vmenu *Gvm = Vmenu_new(Gmenu);
    Vmenu *Wvm = Vmenu_new(Wmenu);
+   Vmenu *Mvm = Vmenu_new(Mmenu);                                                //  OSM                                16.05
    Vmenu *Xvm;
+
    int   iz = iconsize;
 
    for (me = 0; me < Nmenus; me++)
@@ -654,7 +696,8 @@ void build_widgets()
 
       if (me < NFmenu) Xvm = Fvm;                                                //  F-view menu
       else if (me < NGmenu) Xvm = Gvm;                                           //  G-view
-      else Xvm = Wvm;                                                            //  W-view
+      else if (me < NWmenu) Xvm = Wvm;                                           //  W-view                        OSM  16.05
+      else Xvm = Mvm;                                                            //  M-view                        OSM  16.05
 
       if (menutab[me].topmenu)                                                   //  submenu within top menu
          add_popmenu_item(menutab[me].topmenu, menutab[me].menu,
@@ -670,7 +713,7 @@ void build_widgets()
                Vmenu_add(Xvm, menutab[me].menu, 0, 0, 0, menutab[me].desc,
                               menutab[me].func, menutab[me].arg);
          }
-         else  /* both */
+         else  /* menus and icons */
             Vmenu_add(Xvm, menutab[me].menu, menutab[me].icon, iz, iz,
                            menutab[me].desc, menutab[me].func, menutab[me].arg);
       }
@@ -766,38 +809,40 @@ void build_widgets()
 
 /********************************************************************************/
 
-//  set window view mode, F/G/W
+//  set window view mode, F/G/W/M
 
-void m_viewmode(GtkWidget *, cchar *fgw)
+void m_viewmode(GtkWidget *, cchar *fgwm)
 {
    zthreadcrash();
 
-   if (FGW == *fgw) return;                                                      //  no change
+   if (FGWM == *fgwm) return;                                                    //  no change
 
-   if (*fgw == 'F')                                                              //  set F view mode for image file
+   if (*fgwm == 'F')                                                             //  set F view mode for image file
    {
       F1_help_topic = "file_view";
 
       gtk_widget_hide(Ghbox);
       gtk_widget_hide(Whbox);
+      gtk_widget_hide(Mhbox);                                                    //  OSM                                16.05
       gtk_widget_show_all(Fhbox);
       set_mwin_title();
-      FGW = 'F';
+      FGWM = 'F';
 
       Cstate = &Fstate;                                                          //  set drawing area
       Cdrawin = Fdrawin;
       gdkwin = gtk_widget_get_window(Fdrawin);                                   //  GDK window
    }
 
-   if (*fgw == 'G')                                                              //  set G view mode for thumbnail gallery
+   if (*fgwm == 'G')                                                             //  set G view mode for thumbnail gallery
    {
       if (CEF) return;                                                           //  don't interrupt edit func.         15.04
       if (Fslideshow) return;                                                    //  no crash slide show                15.02
 
       gtk_widget_hide(Fhbox);
       gtk_widget_hide(Whbox);
+      gtk_widget_hide(Mhbox);                                                    //  OSM                                16.05
       gtk_widget_show_all(Ghbox);
-      FGW = 'G';
+      FGWM = 'G';
 
       Cstate = 0;                                                                //  no F/W image drawing area
       Cdrawin = 0;
@@ -807,7 +852,7 @@ void m_viewmode(GtkWidget *, cchar *fgw)
       else gallery(0,"paint",-1);                                                //  else leave unchanged
    }
 
-   if (*fgw == 'W')                                                              //  set W view mode for geomaps
+   if (*fgwm == 'W')                                                             //  set W view mode for geomaps
    {
       if (CEF) return;                                                           //  don't interrupt edit func.         15.04
       if (Fslideshow) return;                                                    //  no crash slide show                15.10
@@ -816,17 +861,39 @@ void m_viewmode(GtkWidget *, cchar *fgw)
 
       gtk_widget_hide(Fhbox);                                  
       gtk_widget_hide(Ghbox);
+      gtk_widget_hide(Mhbox);                                                    //  OSM                                16.05
       gtk_widget_show_all(Whbox);
-      FGW = 'W';
+      FGWM = 'W';
 
       Cstate = &Wstate;                                                          //  set drawing area
       Cdrawin = Wdrawin;
       gdkwin = gtk_widget_get_window(Wdrawin);                                   //  GDK window
 
+      if (! Wstate.fpxb) m_load_geomap(0,"default");                             //  no map loaded, load default map 
+
       gtk_window_set_title(MWIN,ZTX("Image Locations"));                         //  window title
       Fpaintnow();
+   }
 
-      if (! Wstate.fpxb) m_load_geomap(0,"default");                             //  no map loaded, load default map 
+   if (*fgwm == 'M')                                                             //  OSM                                16.05
+   {
+      if (CEF) return;                                                           //  don't interrupt edit func.
+      if (Fslideshow) return;                                                    //  no crash slide show
+
+      F1_help_topic = "OSM_maps_view";
+
+      gtk_widget_hide(Fhbox);                                  
+      gtk_widget_hide(Ghbox);
+      gtk_widget_hide(Whbox);
+      gtk_widget_show_all(Mhbox);
+      FGWM = 'M';
+
+      Cstate = 0;                                                                //  no F/W image drawing area
+      Cdrawin = 0;
+      gdkwin = 0;
+      
+      m_load_OSM_map(0,"init");                                                  //  load OSM initial map
+      gtk_window_set_title(MWIN,ZTX("Image Locations"));                         //  window title
    }
 
    return;
@@ -887,7 +954,7 @@ void gallery_Lclick_func(int Nth)
 {
    char     *file;
 
-   if (checkpend("block")) return;                                               //  15.08
+   if (checkpend("busy block mods")) return;                                     //  bugfix                             16.05
    file = gallery(0,"find",Nth);
    if (! file) return;
    f_open(file,Nth,0,1);                                                         //  clicked file >> current file
@@ -901,20 +968,20 @@ void gallery_Lclick_func(int Nth)
 
 void gallery_Rclick_popup(int Nth)
 {
-   int      ftyp;
+   FTYPE    ftype;
 
    clicked_posn = Nth;                                                           //  clicked gallery position (0 base)
    clicked_file = gallery(0,"find",Nth);                                         //  clicked_file is subject for zfree()
    if (! clicked_file) return;
-   ftyp = image_file_type(clicked_file);
+   ftype = image_file_type(clicked_file);
 
-   if (navi::gallerytype == 4)                                                   //  gallery type is album
+   if (navi::gallerytype == ALBUM)                                               //  gallery type is album
       popup_menu(Mwin,popmenu_album);
 
-   else if (ftyp == 2)                                                           //  clicked thumbnail is an image file
+   else if (ftype == IMAGE)                                                      //  clicked thumbnail is an image file
       popup_menu(Mwin,popmenu_thumb);
 
-   else if (ftyp == 3)                                                           //  clicked thumbnail is a RAW file
+   else if (ftype == RAW)                                                        //  clicked thumbnail is a RAW file
       popup_menu(Mwin,popmenu_raw);
 
    return;
@@ -930,7 +997,7 @@ void m_favorites(GtkWidget *, cchar *)
 
    F1_help_topic = "favorites_menu";
    snprintf(menuconfigfile,200,"%s/menu-config",favorites_dirk);
-   gmenuz(Mwin,"Fav",menuconfigfile,favorites_callback);
+   gmenuz(Mwin,"Favorites",menuconfigfile,favorites_callback);
    return;
 }
 
@@ -942,12 +1009,16 @@ void favorites_callback(cchar *menu)
 {
    int      ii;
 
-   m_viewmode(0,"F");
-   
-   if (menu && strmatch(menu,"quit")) return;                                    //  16.02
+   if (! menu) return;                                                           //  16.04
+   if (strmatchcase(menu,"quit")) return;
 
+   if (strmatchcase(menu,"help")) {                                              //  16.04
+      showz_userguide("favorites_menu");
+      return;
+   }
+   
    for (ii = 0; ii < Nmenus; ii++) {
-      if (! menu || ! menutab[ii].menu) continue;                                //  16.02
+      if (! menutab[ii].menu) continue;                                          //  16.04
       if (strmatchcase(ZTX(menu),ZTX(menutab[ii].menu))) break;
    }
 
