@@ -1,4 +1,4 @@
-/**************************************************************************
+/********************************************************************************
    zfuncs.h      include file for zfuncs functions
 
    Copyright 2006-2016 Michael Cornelison
@@ -18,9 +18,9 @@
    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-***************************************************************************/
+*********************************************************************************/
 
-//     zfuncs.h   version  v.6.2
+//     zfuncs.h   version  v.6.3
 
 #include <sys/sysinfo.h>
 #include <sys/time.h>
@@ -59,6 +59,7 @@
 #define  uint64  unsigned long long
 #define  uchar  unsigned char
 #define  cchar  const char
+#define  VOL volatile
 
 #define  wstrerror(err) strerror(WEXITSTATUS(err))                               //  get text status for child process
 
@@ -80,7 +81,7 @@
 
 #define TRACE trace(__FILE__,__FUNCTION__,__LINE__,__builtin_return_address(0));
 
-//  system functions ======================================================
+//  system functions ============================================================
 
 void *zmalloc(uint cc);                                                          //  malloc() with counter
 void zfree(void *pp);                                                            //  free() with counter
@@ -141,9 +142,9 @@ int check_create_dir(char *path);
 
 //  measure CPU time spent in a function or code block within a function
 
-extern volatile double cpu_profile_timer;                                        //  internal data tables
-extern volatile double cpu_profile_table[100];
-extern volatile double cpu_profile_elapsed;
+extern VOL double cpu_profile_timer;                                             //  internal data tables
+extern VOL double cpu_profile_table[100];
+extern VOL double cpu_profile_elapsed;
 void cpu_profile_init();                                                         //  initialize at start of test
 void cpu_profile_report();                                                       //  report CPU time per function
 inline void cpu_profile_enter(int fnum)                                          //  at entry to measured code block
@@ -152,7 +153,7 @@ inline void cpu_profile_exit(int fnum)
 {  cpu_profile_table[fnum] += cpu_profile_elapsed - cpu_profile_timer; }
 int pagefaultrate();                                                             //  monitor own process hard fault rate
 
-//  string macros and functions ===========================================
+//  string macros and functions =================================================
 
 #define strmatch(str1,str2) (! strcmp((str1),(str2)))                            //  TRUE if strings equal
 #define strmatchN(str1,str2,cc) (! strncmp((str1),(str2),(cc)))                  //  TRUE if strings[cc] equal
@@ -189,7 +190,7 @@ int  utf8substring(char *utf8out, cchar *utf8in, int pos, int cc);
 int  utf8_check(cchar *string);                                                  //  check utf8 string for encoding errors
 int  utf8_position(cchar *utf8in, int Nth);                                      //  get byte position of Nth graphic char.
 
-//  number conversion =====================================================
+//  number conversion ===========================================================
 
 int convSI (cchar *s, int &i, cchar **delm = 0);                                 //  string to int
 int convSI (cchar *s, int &i, int low, int hi, cchar **delm = 0);                //  (with low/high limit checking)
@@ -201,14 +202,14 @@ int convIS (int iin, char *outp, int *cc = 0);
 int convDS (double din, int prec, char *outp, int *cc = 0);                      //  double to string, precision, ret. cc
 char * formatKBMB(double fnum, int prec);                                        //  format nnn B, nn.n KB, n.nn MB, etc.
 
-//  wildcard functions ====================================================
+//  wildcard functions ==========================================================
 
 int MatchWild(cchar * wildstr, cchar * str);                                     //  wildcard string match (match = 0)
 int MatchWildIgnoreCase(cchar * wildstr, cchar * str);                           //  wildcard string match, ignoring case
 cchar * SearchWild(cchar *wpath, int &flag);                                     //  wildcard file search
 cchar * SearchWildIgnoreCase(cchar *wpath, int &flag);                           //  wildcard file search, ignoring case
 
-//  search and sort functions =============================================
+//  search and sort functions ===================================================
 
 int bsearch(int seekint, int nn, int list[]);                                    //  binary search sorted list[nn]
 int bsearch(cchar *seekrec, cchar *allrecs, int recl, int nrecs);                //  binary search sorted records
@@ -225,7 +226,7 @@ void HeapSort(char *recs, int RL, int NR, HeapSortUcomp);
 
 int MemSort(char * RECS, int RL, int NR, int KEYS[][3], int NK);                 //  memory sort, records with multiple keys
 
-//  variable string list functions ========================================
+//  variable string list functions ==============================================
 
 struct  pvlist {
    int      max;                          //  max. entries
@@ -245,19 +246,19 @@ int pvlist_replace(pvlist *pv, int Nth, cchar *entry);
 char * pvlist_get(pvlist *pv, int Nth);                                          //  return Nth entry (0...)
 int pvlist_sort(pvlist *pv);                                                     //  sort list, ascending
 
-//  random number functions ===============================================
+//  random number functions =====================================================
 
 int lrandz(int64 * seed);                                                        //  returns 0 to 0x7fffffff
 int lrandz();                                                                    //  built-in seed
 double drandz(int64 * seed);                                                     //  returns 0.0 to 0.99999...
 double drandz();                                                                 //  built-in seed
 
-//  spline curve-fitting functions ========================================
+//  spline curve-fitting functions ==============================================
 
 void spline1(int nn, float *dx, float *dy);                                      //  define a curve using nn data points
 float spline2(float x);                                                          //  return y-value for given x-value
 
-//  FIFO queue for text strings, single or dual-thread access =============
+//  FIFO queue for text strings, single or dual-thread access ===================
 
 typedef struct  {
    int      qcap;                                                                //  queue capacity
@@ -272,25 +273,29 @@ void Qtext_put(Qtext *qtext, cchar *format, ...);
 char * Qtext_get(Qtext *qtext);                                                  //  remove text string from Qtext queue
 void Qtext_close(Qtext *qtext);                                                  //  close Qtext, zfree() leftover strings
 
-//  application initialization and administration =========================
+//  application initialization and administration ===============================
 
 int zinitapp(cchar *appname);                                                    //  initz. app directories and files
+
 cchar * get_zprefix();                                                           //  get /usr or /usr/local  ... 
 cchar * get_zuserdir();                                                          //  get /home/user/.appname/
 cchar * get_zdatadir();                                                          //  get data directory
 cchar * get_zdocdir();                                                           //  get document directory
 cchar * get_zicondir();                                                          //  get icon directory
+
+void get_hardware_info(GtkWidget *widget = 0);                                   //  get display, screen, mouse, gtksettings
+void zsetfont(cchar *newfont);                                                   //  set new app font and size
+
 int  locale_filespec(cchar *ftype, cchar *fname, char *filespec);                //  get a locale dependent file
 
 void showz_userguide(cchar *context = 0);                                        //  show user guide in new process
 void showz_logfile();                                                            //  show log file in popup window
 void showz_textfile(cchar *type, cchar *file);                                   //  show text file [.gz] in popup window
 void showz_html(cchar *url);                                                     //  show html via preferred browser
-void zmake_menu_launcher(cchar *command, cchar *cats, cchar *generic);           //  add desktop menu and launcher
 
-/**************************************************************************/
+void zmake_menu_launcher(cchar *command, cchar *cats, cchar *generic);           //  make desktop menu and launcher
 
-//  translation functions
+//  translation functions =======================================================
 
 #define ZTXmaxent 2000                                                           //  max. translation strings
 #define ZTXmaxcc 4000                                                            //  max. cc per string
@@ -299,21 +304,21 @@ void ZTXinit(cchar *lang);
 cchar * ZTX(cchar *english);                                                     //  get translation for English message
 cchar * ZTX_missing(int &ftf);                                                   //  get missing translations, one per call
 
-/**************************************************************************
+/********************************************************************************
    GTK utility functions
-***************************************************************************/
+*********************************************************************************/
 
 void zmainloop(int skip = 0);                                                    //  do main loop, process menu events
 void zthreadcrash();                                                             //  crash if thread is not main() thread
 
-void get_hardware_info(GtkWidget *widget = 0);                                   //  get display, screen, mouse
-int  move_pointer(GtkWidget *, int px, int py);                                  //  move the mouse pointer to px, py
-
 //  text window print and read utilities
 
 void wprintx(GtkWidget *Win, int line, cchar *mess, int bold = 0);               //  write text to line, optional bold
 void wprintf(GtkWidget *Win, int line, cchar *format, ...);                      //  "printf" version
 void wprintf(GtkWidget *Win, cchar *format, ... );                               //  "printf" to next line, scroll up
+void wprintxx(GtkWidget *Win, int line, cchar *mess, int bold = 0);              //  alternate with auto zmainloop()
+void wprintff(GtkWidget *Win, int line, cchar *format, ...);                     //  alternate with auto zmainloop()
+void wprintff(GtkWidget *Win, cchar *format, ... );                              //  alternate with auto zmainloop()
 void wscroll(GtkWidget *mLog, int line);                                         //  scroll window to put line on screen
 void wclear(GtkWidget *Win);                                                     //  clear window
 void wclear(GtkWidget *Win, int line);                                           //  clear from line to end
@@ -350,14 +355,14 @@ GtkWidget * add_toolbar_button(GtkWidget *tbar, cchar *lab, cchar *tip,
 GtkWidget * create_stbar(GtkWidget *vbox);                                       //  create status bar in packing box
 int stbar_message(GtkWidget *stbar, cchar *message);                             //  display message in status bar
 
-/**************************************************************************/
+/********************************************************************************/
 
 GtkWidget * create_popmenu();                                                    //  create an empty popup menu
 GtkWidget * add_popmenu_item(GtkWidget *popmenu, cchar *mname,                   //  add menu item to popup menu
                            cbFunc func, cchar *arg, cchar *mtip = 0);
 void popup_menu(GtkWidget *, GtkWidget *popmenu);                                //  pop-up menu at current mouse posn.
 
-/**************************************************************************/
+/********************************************************************************/
 
 //  user editable graphic menu in popup window
 //  menus can be added and arranged using the mouse
@@ -365,7 +370,7 @@ void popup_menu(GtkWidget *, GtkWidget *popmenu);
 typedef void gmenuz_cbfunc(cchar *menu);                                         //  caller-supplied callback function
 void gmenuz(GtkWidget *parent, cchar *title, cchar *ufile, gmenuz_cbfunc);       //  show window, handle mouse drag/click
 
-/**************************************************************************/
+/********************************************************************************/
 
 //  create vertical menu/toolbar in vertical packing box                         //  v.5.5
 
@@ -396,7 +401,7 @@ void Vmenu_add(Vmenu *vbm, cchar *name, cchar *icon,
                int iconww, int iconhh, cchar *desc,
                cbFunc func, cchar *arg);                                         //  function may be popup_menu()
 
-/**************************************************************************/
+/********************************************************************************/
 
 //   functions to implement GTK dialogs with less complexity
 //   widget types: dialog, hbox, vbox, hsep, vsep, frame, scrwin, label, entry, edit, radio,
@@ -511,7 +516,6 @@ int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent
 //  popup message dialogs
 
 void zmessageACK(GtkWidget *parent, cchar *format, ... );                           //  display message, wait for OK
-void zmessLogACK(GtkWidget *parent, cchar *format, ... );                           //  same, with log to STDOUT
 int  zmessageYN(GtkWidget *parent, cchar *format, ... );                            //  display message, wait for YES/NO
 zdialog * zmessage_post(GtkWidget *parent, int secs, cchar *format, ...);           //  show message, timeout or cancel
 char * zdialog_text(GtkWidget *parent, cchar *title, cchar *inittext);              //  get short text input from user
@@ -543,11 +547,13 @@ PIXBUF * gdk_pixbuf_rotate(PIXBUF *, float deg, int alfa = 0);
 PIXBUF * gdk_pixbuf_stripalpha(PIXBUF *pixbuf);                                  //  strip alpha channel from pixbuf
 PIXBUF * text_pixbuf(cchar *text, cchar *font, int fsize, GtkWidget *);          //  create pixbuf with text using font
 
-/**************************************************************************
-   C++ classes
-***************************************************************************/
+int  move_pointer(GtkWidget *, int px, int py);                                  //  move the mouse pointer to px, py
 
-//  dynamic string class ==================================================
+/********************************************************************************
+   C++ classes
+*********************************************************************************/
+
+//  dynamic string class ========================================================
 
 class xstring
 {
@@ -575,7 +581,7 @@ class xstring
       int getcc() const { return xcc; }                                          //  return string length
 };
 
-//  vector (array) of xstring =============================================
+//  vector (array) of xstring ===================================================
 
 class Vxstring
 {
@@ -595,7 +601,7 @@ public:
    int getCount() const { return nd; }                                           //  get current count
 };
 
-//  hash table class ======================================================
+//  hash table class ============================================================
 
 class HashTab
 {
@@ -616,7 +622,7 @@ public:
    int Dump();                                                                   //  dump hash table
 };
 
-//  Queue class, FIFO, LIFO or mixed ======================================
+//  Queue class, FIFO, LIFO or mixed ============================================
 
 class  Queue
 {
@@ -641,7 +647,7 @@ public:
    xstring * popN();                                                             //  get Nth entry (newest)
 };
 
-/*  =======================================================================
+/*  =============================================================================
 
        Tree class - sparse array indexed by names or numbers
                   - every element of a Tree is a Tree
